# PyClk Python Package Manager
> This is the perfect tool for handling regular or monorepos for python projects. 

## Install
```bash
pip install pyclk
```


## Documentation
After installation, you can run
```bash
pyclk
```
